@@ -44,7 +44,7 @@
 #include <gtk/gtkcombobox.h>
 #include <glib/gstdio.h>
 #include "girl.h"
-#include "girl-player-frontend.h"
+#include "girl-player.h"
 #include "girl-gui.h"
 #include "girl-program.h"
 #include "girl-station.h"
@@ -53,6 +53,7 @@
 
 extern GtkWidget *girl_app;
 extern GtkWidget *search_selector;
+extern GstPlayer *player;
 
 GnomeUIInfo toolbar[] = {
 	GNOMEUIINFO_ITEM_STOCK(N_("New"), N_("Add a new radio station"),
@@ -516,7 +517,7 @@ on_search_matches(GtkEntryCompletion *widget,
 			girl->selected_station_location,
 			girl->selected_station_uri);
 
-	girl_player_frontend_stop (girl->player_window, NULL);
+	girl_player_stop (player);
 
 	if (GTK_IS_WIDGET(search_selector)) {
 		gtk_widget_destroy(search_selector);
