@@ -2,7 +2,7 @@
  *
  * GNOME Internet Radio Locator
  *
- * Copyright (C) 2016  Ole Aamot Software
+ * Copyright (C) 2014, 2015  Ole Aamot Software
  *
  * Author: Ole Aamot <oka@oka.no>
  *
@@ -21,11 +21,36 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef __GIRL_PLAYER__
-#define __GIRL_PLAYER__
+#ifndef GIRL_PLAYER_H
+#define GIRL_PLAYER_H
 
-void girl_player_main(gchar *streamuri, gchar *name);
+#include <gst/gst.h>
+#include <gst/player/player.h>
 
-#endif /* __GIRL_PLAYER__ */
+typedef struct
+{
+  gchar **uris;
+  guint num_uris;
+  gint cur_idx;
 
-	
+  GstPlayer *player;
+  GstState desired_state;
+
+  gboolean repeat;
+
+  GMainLoop *loop;
+} GstPlay;
+
+static void play_uri (GstPlayer * player, const gchar * next_uri);
+
+void girl_player_new (GstPlayer * player, const gchar * next_uri);
+
+void girl_player_new (GstPlayer * player, const gchar * next_uri);
+
+void girl_player_quit (GstPlayer *player);
+
+void girl_player_stop (GstPlayer *player);
+
+void girl_player_pause (GstPlayer *player);
+
+#endif /* GIRL_PLAYER_H */
