@@ -44,10 +44,6 @@
 #include <config.h>
 #include "girl.h"
 
-#include "girl-player-frontend.h"
-#include "girl-player-backend.h"
-#include "girl-player-globals.h"
-
 #include "girl-record-backend.h"
 #include "girl-record-frontend.h"
 
