@@ -50,6 +50,7 @@ extern GList *girl_listeners;
 extern GList *girl_streams;
 
 extern GtkWidget *girl_app;
+extern GstPlayer *player;
 
 void show_error(gchar * msg)
 {
@@ -189,7 +190,10 @@ void girl_helper_run(gchar *url, gchar *name, GirlStreamType type, GirlHelperTyp
 	// girl_player_main(url, girl->selected_station_name);
 
 	if (helper == GIRL_STREAM_PLAYER) {
-		girl_player_main(url, girl->selected_station_name);
+		player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
+		girl_player_new(player, url);
+		gst_player_play(player);
+		/* girl_player_main(url, girl->selected_station_name); */
 	}
 
 	if (helper == GIRL_STREAM_RECORD) {
