@@ -2,7 +2,7 @@
  *
  * GNOME Internet Radio Locator
  *
- * Copyright (C) 2014, 2015  Ole Aamot Software
+ * Copyright (C) 2014, 2015, 2017  Ole Aamot Software
  *
  * Author: Ole Aamot <oka@oka.no>
  *
@@ -38,13 +38,13 @@
 #include "girl-listener.h"
 #include "girl-station.h"
 #include "girl-program.h"
-#include "girl-player-frontend.h"
-#include "girl-player-backend.h"
-#include "girl-record-frontend.h"
+#include "girl-player.h"
 #include "girl-record-backend.h"
 
 GirlData *girl;
 
+GstPlayer *player;
+
 GList *girl_archivers;
 GList *girl_listeners;
 GList *girl_programs;
@@ -77,16 +77,6 @@ int main(int argc, char *argv[])
 		exit(1);
 	}
 
-	if (!girl_player_frontend_init (&argc, &argv)) {
-		GIRL_DEBUG_MSG (_("Player Frontend initialization failure..."));
-		exit (0);
-	}
-
-	if (!girl_player_backend_init (&argc, &argv)) {
-		GIRL_DEBUG_MSG (_("Player Backend creation failure"));
-		exit (0);
-	}
-
 	gst_init(&argc, &argv);
 
 	gnome_program_init(PACKAGE, VERSION,
@@ -230,7 +220,7 @@ void on_previous_station_click(GtkWidget * a, gpointer user_data)
 void on_next_station_click(GtkWidget * a, gpointer user_data)
 {
 	GList *l = g_list_first(girl_stations);
-	girl_player_frontend_stop (girl->player_window, NULL);
+	girl_player_stop(player);
 	girl->previous_station = (GirlStationInfo*)girl->selected_station;
 	if (l != NULL) {
 		GirlStationInfo *station = l->data;
@@ -479,7 +469,7 @@ void on_stations_selector_changed(GtkWidget * a, gpointer user_data)
 
 	station->name = g_strdup(g_object_get_data(G_OBJECT(a), "station_name"));
 	/* girl_history = g_list_add(GLIST(girl_history), (GirlStationInfo *)station); */
-	girl_player_frontend_stop(girl->player_window, NULL);
+	girl_player_stop(player);
 	girl_helper_run(girl->selected_station_uri,
 			girl->selected_station_name,
 			GIRL_STREAM_SHOUTCAST,
@@ -639,18 +629,13 @@ void quit_app(GtkWidget * a, gpointer user_data)
 		gtk_widget_destroy(girl->player_window);
 	}
 	/* gtk_widget_destroy(girl->record_window); */
-	if (g_main_loop_is_running (girl->player_loop)) {
-		girl_player_backend_stop(girl->player_loop);
-		girl->player_loop = NULL;
-	}
+	girl_player_stop(player);
+	gst_deinit();
+	girl->player_loop = NULL;
 	if (GTK_IS_WIDGET(girl->record_window)) {
 		gtk_widget_destroy(girl->record_window);
 	}
-	if (g_main_loop_is_running (girl->record_loop)) {
-		girl_record_backend_stop(girl->record_loop);
-		girl->record_loop = NULL;
-	}
-	/* girl_record_backend_stop(girl->record_loop); */
+	girl->record_loop = NULL;
 	gtk_main_quit();
 }
 
@@ -953,12 +938,15 @@ void on_stop_button_clicked(GtkWidget *a, gpointer user_data)
 		
 	}
 
-	girl_player_backend_pause();
+	/* girl_player_backend_pause(); */
 	if (GTK_IS_WIDGET(girl->player_window)) {
 		gtk_widget_destroy(girl->player_window);
 	}
 
+	girl_player_stop(player);
+
 	if (girl->player_status == GIRL_PLAYER_TRUE) {
+
 		GIRL_DEBUG_MSG("Playback stopped.\n");
 		g_subprocess_force_exit(girl->player_subprocess);
 		// g_spawn_close_pid( girl->player_pid);
